/**
 * YNAB API Endpoints
 * Our API uses a REST based design, leverages the JSON data format, and relies upon HTTPS for transport. We respond with meaningful HTTP response codes and if an error occurs, we include error details in the response body.  API Documentation is at https://api.youneedabudget.com
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { CategoriesResponse } from '../model/categoriesResponse';
import { CategoryResponse } from '../model/categoryResponse';
import { SaveMonthCategoryWrapper } from '../model/saveMonthCategoryWrapper';
import { Configuration } from '../configuration';
export declare class CategoriesService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * List categories
     * Returns all categories grouped by category group.  Amounts (budgeted, activity, balance, etc.) are specific to the current budget month (UTC).
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param lastKnowledgeOfServer The starting server knowledge.  If provided, only entities that have changed since last_knowledge_of_server will be included.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCategories(budgetId: string, lastKnowledgeOfServer?: number, observe?: 'body', reportProgress?: boolean): Observable<CategoriesResponse>;
    getCategories(budgetId: string, lastKnowledgeOfServer?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CategoriesResponse>>;
    getCategories(budgetId: string, lastKnowledgeOfServer?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CategoriesResponse>>;
    /**
     * Single category
     * Returns a single category.  Amounts (budgeted, activity, balance, etc.) are specific to the current budget month (UTC).
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param categoryId The id of the category
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getCategoryById(budgetId: string, categoryId: string, observe?: 'body', reportProgress?: boolean): Observable<CategoryResponse>;
    getCategoryById(budgetId: string, categoryId: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CategoryResponse>>;
    getCategoryById(budgetId: string, categoryId: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CategoryResponse>>;
    /**
     * Single category for a specific budget month
     * Returns a single category for a specific budget month.  Amounts (budgeted, activity, balance, etc.) are specific to the current budget month (UTC).
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param month The budget month in ISO format (e.g. 2016-12-01) (\&quot;current\&quot; can also be used to specify the current calendar month (UTC))
     * @param categoryId The id of the category
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getMonthCategoryById(budgetId: string, month: string, categoryId: string, observe?: 'body', reportProgress?: boolean): Observable<CategoryResponse>;
    getMonthCategoryById(budgetId: string, month: string, categoryId: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CategoryResponse>>;
    getMonthCategoryById(budgetId: string, month: string, categoryId: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CategoryResponse>>;
    /**
     * Update a category for a specific month
     * Update a category for a specific month
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param month The budget month in ISO format (e.g. 2016-12-01) (\&quot;current\&quot; can also be used to specify the current calendar month (UTC))
     * @param categoryId The id of the category
     * @param data The category to update
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updateMonthCategory(budgetId: string, month: string, categoryId: string, data: SaveMonthCategoryWrapper, observe?: 'body', reportProgress?: boolean): Observable<CategoryResponse>;
    updateMonthCategory(budgetId: string, month: string, categoryId: string, data: SaveMonthCategoryWrapper, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<CategoryResponse>>;
    updateMonthCategory(budgetId: string, month: string, categoryId: string, data: SaveMonthCategoryWrapper, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<CategoryResponse>>;
}
