/**
 * YNAB API Endpoints
 * Our API uses a REST based design, leverages the JSON data format, and relies upon HTTPS for transport. We respond with meaningful HTTP response codes and if an error occurs, we include error details in the response body.  API Documentation is at https://api.youneedabudget.com
 *
 * OpenAPI spec version: 1.0.0
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 * Do not edit the class manually.
 */
import { HttpClient, HttpHeaders, HttpResponse, HttpEvent } from '@angular/common/http';
import { Observable } from 'rxjs';
import { HybridTransactionsResponse } from '../model/hybridTransactionsResponse';
import { SaveTransactionWrapper } from '../model/saveTransactionWrapper';
import { SaveTransactionsResponse } from '../model/saveTransactionsResponse';
import { SaveTransactionsWrapper } from '../model/saveTransactionsWrapper';
import { TransactionResponse } from '../model/transactionResponse';
import { TransactionsResponse } from '../model/transactionsResponse';
import { Configuration } from '../configuration';
export declare class TransactionsService {
    protected httpClient: HttpClient;
    protected basePath: string;
    defaultHeaders: HttpHeaders;
    configuration: Configuration;
    constructor(httpClient: HttpClient, basePath: string, configuration: Configuration);
    /**
     * @param consumes string[] mime-types
     * @return true: consumes contains 'multipart/form-data', false: otherwise
     */
    private canConsumeForm;
    /**
     * Create a single transaction or multiple transactions
     * Creates a single transaction or multiple transactions.  If you provide a body containing a \&#39;transaction\&#39; object, a single transaction will be created and if you provide a body containing a \&#39;transactions\&#39; array, multiple transactions will be created.
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param data The transaction or transactions to create.  To create a single transaction you can specify a value for the \&#39;transaction\&#39; object and to create multiple transactions you can specify an array of \&#39;transactions\&#39;.  It is expected that you will only provide a value for one of these objects.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    createTransaction(budgetId: string, data: SaveTransactionsWrapper, observe?: 'body', reportProgress?: boolean): Observable<SaveTransactionsResponse>;
    createTransaction(budgetId: string, data: SaveTransactionsWrapper, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<SaveTransactionsResponse>>;
    createTransaction(budgetId: string, data: SaveTransactionsWrapper, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<SaveTransactionsResponse>>;
    /**
     * Single transaction
     * Returns a single transaction
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param transactionId The id of the transaction
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransactionById(budgetId: string, transactionId: string, observe?: 'body', reportProgress?: boolean): Observable<TransactionResponse>;
    getTransactionById(budgetId: string, transactionId: string, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TransactionResponse>>;
    getTransactionById(budgetId: string, transactionId: string, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TransactionResponse>>;
    /**
     * List transactions
     * Returns budget transactions
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param sinceDate If specified, only transactions on or after this date will be included.  The date should be ISO formatted (e.g. 2016-12-30).
     * @param type If specified, only transactions of the specified type will be included. \&#39;uncategorized\&#39; and \&#39;unapproved\&#39; are currently supported.
     * @param lastKnowledgeOfServer The starting server knowledge.  If provided, only entities that have changed since last_knowledge_of_server will be included.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransactions(budgetId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'body', reportProgress?: boolean): Observable<TransactionsResponse>;
    getTransactions(budgetId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TransactionsResponse>>;
    getTransactions(budgetId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TransactionsResponse>>;
    /**
     * List account transactions
     * Returns all transactions for a specified account
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param accountId The id of the account
     * @param sinceDate If specified, only transactions on or after this date will be included.  The date should be ISO formatted (e.g. 2016-12-30).
     * @param type If specified, only transactions of the specified type will be included. \&#39;uncategorized\&#39; and \&#39;unapproved\&#39; are currently supported.
     * @param lastKnowledgeOfServer The starting server knowledge.  If provided, only entities that have changed since last_knowledge_of_server will be included.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransactionsByAccount(budgetId: string, accountId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'body', reportProgress?: boolean): Observable<TransactionsResponse>;
    getTransactionsByAccount(budgetId: string, accountId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TransactionsResponse>>;
    getTransactionsByAccount(budgetId: string, accountId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TransactionsResponse>>;
    /**
     * List category transactions
     * Returns all transactions for a specified category
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param categoryId The id of the category
     * @param sinceDate If specified, only transactions on or after this date will be included.  The date should be ISO formatted (e.g. 2016-12-30).
     * @param type If specified, only transactions of the specified type will be included. \&#39;uncategorized\&#39; and \&#39;unapproved\&#39; are currently supported.
     * @param lastKnowledgeOfServer The starting server knowledge.  If provided, only entities that have changed since last_knowledge_of_server will be included.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransactionsByCategory(budgetId: string, categoryId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'body', reportProgress?: boolean): Observable<HybridTransactionsResponse>;
    getTransactionsByCategory(budgetId: string, categoryId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<HybridTransactionsResponse>>;
    getTransactionsByCategory(budgetId: string, categoryId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<HybridTransactionsResponse>>;
    /**
     * List payee transactions
     * Returns all transactions for a specified payee
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param payeeId The id of the payee
     * @param sinceDate If specified, only transactions on or after this date will be included.  The date should be ISO formatted (e.g. 2016-12-30).
     * @param type If specified, only transactions of the specified type will be included. \&#39;uncategorized\&#39; and \&#39;unapproved\&#39; are currently supported.
     * @param lastKnowledgeOfServer The starting server knowledge.  If provided, only entities that have changed since last_knowledge_of_server will be included.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    getTransactionsByPayee(budgetId: string, payeeId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'body', reportProgress?: boolean): Observable<HybridTransactionsResponse>;
    getTransactionsByPayee(budgetId: string, payeeId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<HybridTransactionsResponse>>;
    getTransactionsByPayee(budgetId: string, payeeId: string, sinceDate?: string, type?: 'uncategorized' | 'unapproved', lastKnowledgeOfServer?: number, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<HybridTransactionsResponse>>;
    /**
     * Updates an existing transaction
     * Updates a transaction
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param transactionId The id of the transaction
     * @param data The transaction to update
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updateTransaction(budgetId: string, transactionId: string, data: SaveTransactionWrapper, observe?: 'body', reportProgress?: boolean): Observable<TransactionResponse>;
    updateTransaction(budgetId: string, transactionId: string, data: SaveTransactionWrapper, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<TransactionResponse>>;
    updateTransaction(budgetId: string, transactionId: string, data: SaveTransactionWrapper, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<TransactionResponse>>;
    /**
     * Update multiple transactions
     * Updates multiple transactions, by \&#39;id\&#39; or \&#39;import_id\&#39;.
     * @param budgetId The id of the budget (\&quot;last-used\&quot; can also be used to specify the last used budget)
     * @param data The transactions to update.  Optionally, transaction \&#39;id\&#39; value(s) can be specified as null and an \&#39;import_id\&#39; value can be provided which will allow transaction(s) to updated by their import_id.
     * @param observe set whether or not to return the data Observable as the body, response or events. defaults to returning the body.
     * @param reportProgress flag to report request and response progress.
     */
    updateTransactions(budgetId: string, data: SaveTransactionsWrapper, observe?: 'body', reportProgress?: boolean): Observable<SaveTransactionsResponse>;
    updateTransactions(budgetId: string, data: SaveTransactionsWrapper, observe?: 'response', reportProgress?: boolean): Observable<HttpResponse<SaveTransactionsResponse>>;
    updateTransactions(budgetId: string, data: SaveTransactionsWrapper, observe?: 'events', reportProgress?: boolean): Observable<HttpEvent<SaveTransactionsResponse>>;
}
